#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright © 2020 Michael J. Hayford
""" unit test for Sumita optical glass catalog

.. Created on Wed Aug 26 14:46:13 2020

.. codeauthor: Michael J. Hayford
"""

import unittest
import opticalglass.sumita as su

from opticalglass.test.util import compare_indices


class SumitaTestCase(unittest.TestCase):
    catalog = su.SumitaCatalog()
    # Sumita doesn't tabulate the 's' spectral line
    remove_lines = ['s']

    def test_ohara_catalog_glass_index(self):
        cafk95 = self.catalog.glass_index('K-CaFK95')  # first in list
        self.assertEqual(cafk95, 1)
        pbk40 = self.catalog.glass_index('K-PBK40')
        self.assertEqual(pbk40, 7)
        sk16 = self.catalog.glass_index('K-SK16')
        self.assertEqual(sk16, 64)
        laskn1 = self.catalog.glass_index('K-LaSKn1')
        self.assertEqual(laskn1, 101)
        fir100uv = self.catalog.glass_index('K-FIR100UV')  # last in list
        self.assertEqual(fir100uv, 134)

    def test_sumita_catalog_data_index(self):
        nd = self.catalog.data_index('nd')
        self.assertEqual(nd, 16)
        vd = self.catalog.data_index('vd')
        self.assertEqual(vd, 4)
        B1 = self.catalog.data_index('A4')
        self.assertEqual(B1, 52)
        glasscode = self.catalog.data_index('GTYPE')
        self.assertEqual(glasscode, 2)
        date = self.catalog.data_index('T1_550')
        self.assertEqual(date, 97)

    def test_sumita_glass_pbk40(self):
        glass = su.SumitaGlass('K-PBK40')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'K-PBK40')
        compare_indices(self, glass, SumitaTestCase.catalog, tol=1.1e-5,
                        remove_lines=SumitaTestCase.remove_lines)

    def test_sumita_glass_sk16(self):
        glass = su.SumitaGlass('K-SK16')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'K-SK16')
        compare_indices(self, glass, SumitaTestCase.catalog, tol=4.5e-6,
                        remove_lines=SumitaTestCase.remove_lines)

    def test_sumita_glass_laskn1(self):
        glass = su.SumitaGlass('K-LaSKn1')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'K-LaSKn1')
        compare_indices(self, glass, SumitaTestCase.catalog, tol=7.5e-6,
                        remove_lines=SumitaTestCase.remove_lines)


if __name__ == '__main__':
    unittest.main(verbosity=2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" unit test for Hoya optical glass catalog

.. codeauthor: Michael J. Hayford
"""

import unittest
import opticalglass.hoya as h

from opticalglass.test.util import compare_indices


class HoyaTestCase(unittest.TestCase):
    catalog = h.HoyaCatalog()

    def test_hoya_catalog_glass_index(self):
        fc5 = self.catalog.glass_index('FC5')  # first in list
        self.assertEqual(fc5, 1)
        fcd1 = self.catalog.glass_index('FCD1')
        self.assertEqual(fcd1, 2)
        ef2 = self.catalog.glass_index('E-F2')
        self.assertEqual(ef2, 29)
        bsc7 = self.catalog.glass_index('BSC7')
        self.assertEqual(bsc7, 12)
        mctaf1 = self.catalog.glass_index('MC-TAF1')  # last in list
        self.assertEqual(mctaf1, 194)

    def test_hoya_catalog_data_index(self):
        nd = self.catalog.data_index('nd')
        self.assertEqual(nd, 5)
        vd = self.catalog.data_index('νd')
        self.assertEqual(vd, 6)
        A0 = self.catalog.data_index('A0')
        self.assertEqual(A0, 29)
        n1529 = self.catalog.data_index('n1529.6')
        self.assertEqual(n1529, 11)

    def test_hoya_glass_fcd1(self):
        fcd1 = h.HoyaGlass('FCD1')
        self.assertIsNotNone(fcd1.gindex)
        self.assertEqual(fcd1.name(), 'FCD1')
        compare_indices(self, fcd1, HoyaTestCase.catalog)

    def test_hoya_glass_ef2(self):
        ef2 = h.HoyaGlass('E-F2')
        self.assertIsNotNone(ef2.gindex)
        self.assertEqual(ef2.name(), 'E-F2')
        compare_indices(self, ef2, HoyaTestCase.catalog)

    def test_hoya_glass_bsc7(self):
        bsc7 = h.HoyaGlass('BSC7')
        self.assertIsNotNone(bsc7.gindex)
        self.assertEqual(bsc7.name(), 'BSC7')
        compare_indices(self, bsc7, HoyaTestCase.catalog)


if __name__ == '__main__':
    unittest.main(verbosity=2)



#!/usr/bin/env python
# coding: utf-8

# In[1]:


import numpy as np


# In[2]:


import matplotlib.pyplot as plt


# In[3]:


import opticalglass as og
import opticalglass.glassmap as gm
from opticalglass.glassfactory import create_glass


# In[4]:


bk7 = create_glass('N-BK7', 'Schott')
bk7


# In[5]:


str(bk7)


# In[6]:


bk7.glass_code()


# In[7]:


nd = bk7.rindex('d')
nF = bk7.rindex('F')
nC = bk7.rindex('C')
nC, nd, nF


# In[8]:


vd, PFd = og.glass.calc_glass_constants(nd, nF, nC)
nd, vd, PFd


# In[9]:


dFC = nF-nC
vd = (nd - 1.0)/dFC
PFd = (nF-nd)/dFC
nd, vd, PFd


# In[10]:


bk7.rindex(555.0)


# In[11]:


wl = []
rn = []
for i in np.linspace(365., 700., num=75):
    wl.append(i)
    rn.append(bk7.rindex(i))
plt.plot(wl, rn)


# In[12]:


gmf = plt.figure(FigureClass=gm.GlassMapFigure,
                 glass_db=gm.GlassMapDB()).plot()


# In[ ]:







#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" unit test for Schott optical glass catalog

.. codeauthor: Michael J. Hayford
"""

import unittest
import opticalglass.schott as s

from opticalglass.test.util import compare_indices


class SchottTestCase(unittest.TestCase):
    catalog = s.SchottCatalog()

    def test_schott_catalog_glass_index(self):
        f2 = self.catalog.glass_index('F2')
        self.assertEqual(f2, 0)
        nbk7 = self.catalog.glass_index('N-BK7')
        self.assertEqual(nbk7, 25)
        sf6ht = self.catalog.glass_index('SF6HT')
        self.assertEqual(sf6ht, 122)

    def test_schott_catalog_data_index(self):
        nd = self.catalog.data_index('nd')
        self.assertEqual(nd, 1)
        vd = self.catalog.data_index('vd')
        self.assertEqual(vd, 3)
        B1 = self.catalog.data_index('B1')
        self.assertEqual(B1, 6)
        glasscode = self.catalog.data_index('Glascode')
        self.assertEqual(glasscode, 158)
        date = self.catalog.data_index('Date')
        self.assertEqual(date, 160)

    def test_schott_glass_f2(self):
        f2 = s.SchottGlass('F2')
        self.assertIsNotNone(f2.gindex)
        self.assertEqual(f2.name(), 'F2')
        compare_indices(self, f2, SchottTestCase.catalog, tol=5e-6)

    def test_schott_glass_nbk7(self):
        nbk7 = s.SchottGlass('N-BK7')
        self.assertIsNotNone(nbk7.gindex)
        self.assertEqual(nbk7.name(), 'N-BK7')
        compare_indices(self, nbk7, SchottTestCase.catalog, tol=5e-6)

    def test_schott_glass_sf6ht(self):
        sf6ht = s.SchottGlass('SF6HT')
        self.assertIsNotNone(sf6ht.gindex)
        self.assertEqual(sf6ht.name(), 'SF6HT')
        compare_indices(self, sf6ht, SchottTestCase.catalog, tol=5e-6)


if __name__ == '__main__':
    unittest.main(verbosity=2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" unit test for CDGM optical glass catalog

.. codeauthor: Michael J. Hayford
"""

import unittest
import opticalglass.cdgm as c

from opticalglass.test.util import compare_indices


class CDGMTestCase(unittest.TestCase):
    catalog = c.CDGMCatalog()

    def test_cdgm_catalog_glass_index(self):
        g1 = self.catalog.glass_index('H-FK61')  # first in list
        self.assertEqual(g1, 0)
        g2 = self.catalog.glass_index('H-QK3L')
        self.assertEqual(g2, 4)
        g3 = self.catalog.glass_index('F4')
        self.assertEqual(g3, 97)
        g4 = self.catalog.glass_index('H-K9L')
        self.assertEqual(g4, 13)
        g5 = self.catalog.glass_index('D-LaF50')
        self.assertEqual(g5, 229)
        g6 = self.catalog.glass_index('D-ZLaF85L')  # last in list
        self.assertEqual(g6, 239)

    def test_cdgm_catalog_data_index(self):
        nd = self.catalog.data_index('nd')
        self.assertEqual(nd, 9)
        vd = self.catalog.data_index('υd')
        self.assertEqual(vd, 17)
        A0 = self.catalog.data_index('A0')
        self.assertEqual(A0, 21)
        nt = self.catalog.data_index('nt')
        self.assertEqual(nt, 2)

    def test_cdgm_glass_hfk61(self):
        glass = c.CDGMGlass('H-FK61')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'H-FK61')
        compare_indices(self, glass, CDGMTestCase.catalog, tol=6e-6)

    def test_cdgm_glass_f4(self):
        glass = c.CDGMGlass('F4')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'F4')
        compare_indices(self, glass, CDGMTestCase.catalog, tol=1.1e-5)

    def test_cdgm_glass_hk9l(self):
        glass = c.CDGMGlass('H-K9L')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'H-K9L')
        compare_indices(self, glass, CDGMTestCase.catalog, tol=8e-6)


if __name__ == '__main__':
    unittest.main(verbosity=2)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright © 2020 Michael J. Hayford
""" unit test for Hikari glass catalog

.. Created on Wed Aug 26 15:12:40 2020

.. codeauthor: Michael J. Hayford
"""

import unittest
import opticalglass.hikari as hi

from opticalglass.test.util import compare_indices


class HikariTestCase(unittest.TestCase):
    catalog = hi.HikariCatalog()

    def test_hikari_catalog_glass_index(self):
        fk5 = self.catalog.glass_index('J-FK5')  # first in list
        self.assertEqual(fk5, 1)
        bk7a = self.catalog.glass_index('J-BK7A')
        self.assertEqual(bk7a, 11)
        sk16 = self.catalog.glass_index('J-SK16')
        self.assertEqual(sk16, 42)
        lasf02 = self.catalog.glass_index('J-LASF02')
        self.assertEqual(lasf02, 110)
        lasfh24hs = self.catalog.glass_index('J-LASFH24HS')  # last in list
        self.assertEqual(lasfh24hs, 139)

    def test_hikari_catalog_data_index(self):
        nd = self.catalog.data_index(self.catalog.nline_str['d'])
        self.assertEqual(nd, 17)
        vd = self.catalog.data_index('νd')
        self.assertEqual(vd, 25)
        A5 = self.catalog.data_index('A5/λ^6')
        self.assertEqual(A5, 61)
        glasscode = self.catalog.data_index('コードCode(d)')
        self.assertEqual(glasscode, 2)
        date = self.catalog.data_index('550nm')
        self.assertEqual(date, 121)

    def test_hikari_glass_bk7(self):
        glass = hi.HikariGlass('J-BK7A')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'J-BK7A')
        compare_indices(self, glass, HikariTestCase.catalog, tol=4e-6)

    def test_hikari_glass_sk16(self):
        glass = hi.HikariGlass('J-SK16')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'J-SK16')
        compare_indices(self, glass, HikariTestCase.catalog, tol=4.5e-6)

    def test_hikari_glass_lasf02(self):
        glass = hi.HikariGlass('J-LASF02')
        self.assertIsNotNone(glass.gindex)
        self.assertEqual(glass.name(), 'J-LASF02')
        compare_indices(self, glass, HikariTestCase.catalog, tol=2.25e-6)


if __name__ == '__main__':
    unittest.main(verbosity=2)






#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright © 2017 Michael J. Hayford
""" Utilities to support testing of Glass and Glass catalog

.. codeauthor: Michael J. Hayford
"""

spectral_lines = ['t', 's', 'r', 'C', "C'", 'D', 'd',
                  'e', 'F', "F'", 'g', 'h', 'i']


def compare_indices(tc, glass, catalog, tol=5e-6, remove_lines=None):
    """Compare calculated to measured refractive indices at spectral_lines.

    Args:
        tc: the testcase instance for this comparison
        glass: the glass instance being tested
        catalog: the catalog of the glass instance
        tol: the allowed difference between calculated and measured results
        remove_lines: a list of strings **not** to be used in the comparisons,
                      used when data isn't available for that line
    """
    slines = list(spectral_lines)
    if remove_lines is not None:
        for sl in remove_lines:
            slines.remove(sl)
    for sline in slines:
        n_calc = glass.rindex(sline)
        n_meas = glass.meas_rindex(sline)
        tc.assertAlmostEqual(n_calc, n_meas, delta=tol,
                             msg=f"spectral line '{sline:}' outside tol")
